@@ -22,17 +22,10 @@ ProcessIconCache::ProcessIconCache(QObject *parent)
     : QObject(parent)
 {
     qCDebug(app) << "ProcessIconCache object created";
-    // 由于之前获取dapplication::themetypechanged改变信号在有些平台获取不到，现通过获取DPlatformtheme方式获取
-    static QPointer<DPlatformTheme> theme;
-
-    if (!theme) {
-        qCDebug(app) << "DPlatformTheme not set, connecting to iconThemeNameChanged signal";
-        theme = DGuiApplicationHelper::instance()->applicationTheme();
-        connect(theme, &DPlatformTheme::iconThemeNameChanged, this, [ = ]() {
-            qCDebug(app) << "Icon theme changed, clearing pixmap cache";
-            iconPixmapCache.clear();
-        });
-    }
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, [=]() {
+        qCDebug(app) << "Icon theme changed, clearing pixmap cache";
+        iconPixmapCache.clear();
+    });
 }
 
 } // namespace process
